@@ -1,7 +1,7 @@
 package WWW::DaftarNama::Reseller;
 
 our $DATE = '2018-12-17'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -46,7 +46,7 @@ my %args_ns = (
     ns4 => {schema => 'net::hostname*', req=>1},
 );
 
-my %args_info = (
+my %args_contact = (
     firstname => {schema => 'str*', req=>1},
     lastname => {schema => 'str*', req=>1},
     company => {schema => 'str*', req=>1},
@@ -156,7 +156,7 @@ $SPEC{register} = {
 
         periode => {schema => ['int*', between=>[1,10]]},
         %args_ns,
-        %args_info,
+        %args_contact,
     },
 };
 sub register {
@@ -201,15 +201,15 @@ sub renew {
     );
 }
 
-$SPEC{get_info} = {
+$SPEC{get_contact} = {
     v => 1.1,
-    summary => 'Get information for a domain',
+    summary => 'Get contact information for a domain',
     args => {
         %args_common,
         %arg0_domain,
     },
 };
-sub get_info {
+sub get_contact {
     my %args = @_;
     _request(
         action => 'whoisDomain',
@@ -217,23 +217,23 @@ sub get_info {
     );
 }
 
-$SPEC{update_info} = {
+$SPEC{update_contact} = {
     v => 1.1,
-    summary => 'Update information for a domain',
+    summary => 'Update contact information for a domain',
     args => {
         %args_common,
         %arg0_domain,
-        %args_info,
-    },
-};
-sub update_info {
-    my %args = @_;
-    _request(
-        action => 'updateWhois',
+        %args_contact,
         contacttype => {
             schema => ['str*', in=>[qw/all reg admin tech billing/]],
             req => 1,
         },
+    },
+};
+sub update_contact {
+    my %args = @_;
+    _request(
+        action => 'updateWhois',
         %args,
     );
 }
@@ -347,7 +347,7 @@ WWW::DaftarNama::Reseller - Reseller API client for DaftarNama.id
 
 =head1 VERSION
 
-This document describes version 0.001 of WWW::DaftarNama::Reseller (from Perl distribution WWW-DaftarNama-Reseller), released on 2018-12-17.
+This document describes version 0.002 of WWW::DaftarNama::Reseller (from Perl distribution WWW-DaftarNama-Reseller), released on 2018-12-17.
 
 =head1 SYNOPSIS
 
@@ -447,13 +447,13 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 get_epp
+=head2 get_contact
 
 Usage:
 
- get_epp(%args) -> [status, msg, payload, meta]
+ get_contact(%args) -> [status, msg, payload, meta]
 
-Get EPP Code for a domain.
+Get contact information for a domain.
 
 This function is not exported by default, but exportable.
 
@@ -483,13 +483,13 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 get_info
+=head2 get_epp
 
 Usage:
 
- get_info(%args) -> [status, msg, payload, meta]
+ get_epp(%args) -> [status, msg, payload, meta]
 
-Get information for a domain.
+Get EPP Code for a domain.
 
 This function is not exported by default, but exportable.
 
@@ -809,13 +809,13 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 update_info
+=head2 update_contact
 
 Usage:
 
- update_info(%args) -> [status, msg, payload, meta]
+ update_contact(%args) -> [status, msg, payload, meta]
 
-Update information for a domain.
+Update contact information for a domain.
 
 This function is not exported by default, but exportable.
 
@@ -829,6 +829,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<company>* => I<str>
 
+=item * B<contacttype>* => I<str>
+
 =item * B<country>* => I<str>
 
 =item * B<domain>* => I<domain::name>
